@@ -709,7 +709,10 @@ class Resource(object):
                 except Empty:
                     self._add_when_empty()
                 else:
-                    R = self.prepare(R)
+                    try:
+                        R = self.prepare(R)
+                    except BaseException:
+                        self.release_resource(R)
                     self._dirty.add(R)
                     break
         else:
