@@ -18,13 +18,13 @@ from .connection import Resource
 from .messaging import Producer
 from .utils import EqualityDict
 
-__all__ = ["ProducerPool", "PoolGroup", "register_group",
-           "connections", "producers", "get_limit", "set_limit", "reset"]
+__all__ = ['ProducerPool', 'PoolGroup', 'register_group',
+           'connections', 'producers', 'get_limit', 'set_limit', 'reset']
 _limit = [200]
 _used = [False]
 _groups = []
 use_global_limit = object()
-disable_limit_protection = os.environ.get("KOMBU_DISABLE_LIMIT_PROTECTION")
+disable_limit_protection = os.environ.get('KOMBU_DISABLE_LIMIT_PROTECTION')
 
 
 class ProducerPool(Resource):
@@ -32,14 +32,19 @@ class ProducerPool(Resource):
 
     def __init__(self, connections, *args, **kwargs):
         self.connections = connections
-        self.Producer = kwargs.pop("Producer", None) or self.Producer
+        self.Producer = kwargs.pop('Producer', None) or self.Producer
         super(ProducerPool, self).__init__(*args, **kwargs)
 
     def _acquire_connection(self):
         return self.connections.acquire(block=True)
 
     def create_producer(self):
-        return self.Producer(self._acquire_connection())
+        conn = self._acquire_connection()
+        try:
+            return self.Producer(conn)
+        except BaseException:
+            conn.release()
+            raise
 
     def new(self):
         return lambda: self.create_producer()
@@ -49,12 +54,19 @@ class ProducerPool(Resource):
             for _ in xrange(self.limit):
                 self._resource.put_nowait(self.new())
 
+    def close_resource(self, resource):
+        pass
+
     def prepare(self, p):
         if callable(p):
             p = p()
         if not p.channel:
-            connection = self._acquire_connection()
-            p.revive(connection.default_channel)
+            conn = self._acquire_connection()
+            try:
+                p.revive(conn.default_channel)
+            except BaseException:
+                conn.release()
+                raise
         return p
 
     def release(self, resource):
@@ -70,7 +82,7 @@ class PoolGroup(EqualityDict):
         self.limit = limit
 
     def create(self, resource, limit):
-        raise NotImplementedError("PoolGroups must define ``create``")
+        raise NotImplementedError('PoolGroups must define ``create``')
 
     def __missing__(self, resource):
         limit = self.limit
