@@ -25,7 +25,7 @@ class test_Exchange(TestCase):
         bound = exchange.bind(chan)
         self.assertTrue(bound.is_bound)
         self.assertIs(bound.channel, chan)
-        self.assertIn('<bound', repr(bound))
+        self.assertIn('bound to chan', repr(bound))
 
     def test_hash(self):
         self.assertEqual(hash(Exchange('a')), hash(Exchange('a')))
