@@ -49,10 +49,8 @@ class Message(object):
     """Base class for received messages."""
     __slots__ = ('_state', 'channel', 'delivery_tag',
                  'content_type', 'content_encoding',
-                 'delivery_info', 'headers',
-                 'properties', 'body',
-                 '_decoded_cache',
-                 'MessageStateError', '__dict__')
+                 'delivery_info', 'headers', 'properties',
+                 'body', '_decoded_cache', '__dict__')
     MessageStateError = MessageStateError
 
     def __init__(self, channel, body=None, delivery_tag=None,
@@ -205,6 +203,9 @@ class Transport(object):
     #: and that the :meth:`heartbeat_check` method has any effect.
     supports_heartbeats = False
 
+    #: Set to true if the transport supports the AIO interface.
+    supports_ev = False
+
     def __init__(self, client, **kwargs):
         self.client = client
 
@@ -234,6 +235,15 @@ class Transport(object):
         Unconvenient to use, and limited transport support."""
         return {}
 
+    def on_poll_init(self, poller):
+        pass
+
+    def on_poll_start(self):
+        raise NotImplementedError('transport: no eventloop support')
+
+    def on_poll_empty(self):
+        pass
+
     def verify_connection(self, connection):
         return True
 
